@@ -5,10 +5,10 @@ Plugin.create(:api_request_file_cache) do
 
   def gc
     notice "apirequest cache was deleted. "+MikuTwitter::Cache.garbage_collect.inspect
-    Reserver.new(3600){
+    Reserver.new(3600, thread: SerialThread){
       gc }
   end
 
-  Reserver.new(3600){ gc }
+  Reserver.new(3600, thread: SerialThread){ gc }
 
 end
