@@ -7,7 +7,11 @@ Plugin.create :followingcontrol do
   counter = gen_counter
 
   on_period do
-    target = lazy{ Set.new(Service.instances) - @activating_services }
+    target = Enumerator.new{|y|
+      Plugin.filtering(:worlds, y)
+    }.lazy.select{|world|
+      world.class.slug == :twitter and not @activating_services.include?(world)
+    }
     count = counter.call
     if 0 == count % UserConfig["retrieve_interval_followings"]
       rewind(:followings, target) end
@@ -19,7 +23,7 @@ Plugin.create :followingcontrol do
     user = service.user_obj
     users = relation.followings[user]
     if users
-      relation.followings[user] = Users.new((created + users).uniq) end end
+      relation.followings[user] = (created + users).uniq end end
 
   on_followings_destroy do |service, destroyed|
     user = service.user_obj
@@ -31,7 +35,7 @@ Plugin.create :followingcontrol do
     user = service.user_obj
     users = relation.followers[user]
     if users
-      relation.followers[user] = Users.new((created + users).uniq) end end
+      relation.followers[user] = (created + users).uniq end end
 
   on_followers_destroy do |service, destroyed|
     user = service.user_obj
@@ -51,19 +55,19 @@ Plugin.create :followingcontrol do
     container = Gtk::EventBox.new
     userlist = Gtk::UserList.new
     nativewidget container
-    if Service.map(&:user_obj).include?(retriever)
-      userlist.add_user(Users.new((relation.followings[retriever] || []).reverse))
+    if model.me?
+      userlist.add_user((relation.followings[model] || []).reverse)
       events = []
       events << on_followings_created do |service, created|
-        if service.user_obj == retriever
-          userlist.add_user(Users.new(created)) end end
+        if service.user_obj == model
+          userlist.add_user(created) end end
       events << on_followings_destroy do |service, destroyed|
-        if service.user_obj == retriever
-          userlist.remove_user(Users.new(destroyed)) end end
+        if service.user_obj == model
+          userlist.remove_user(destroyed) end end
       events << on_followings_modified do |service, modified|
-        if service.user_obj == retriever
+        if service.user_obj == model
           userlist.listview.model.clear
-          userlist.add_user(Users.new(modified.reverse)) end end
+          userlist.add_user(modified.reverse) end end
       userlist.ssc(:destroy) do
         events.each(&:detach) end
       container.add(userlist).show_all
@@ -71,11 +75,11 @@ Plugin.create :followingcontrol do
       container.ssc_atonce :expose_event do
         loading_image = Gtk::Image.new(Skin['loading.png'].pixbuf(width: 128, height: 128))
         container.add(loading_image.show_all)
-        Service.primary.followings(cache: true, user_id: retriever[:id]).next{ |users|
+        Service.primary.followings(cache: true, user_id: model[:id]).next{ |users|
           container.remove(loading_image)
           loading_image = nil
           container.add(userlist.show_all)
-          userlist.add_user(Users.new(users.reverse))
+          userlist.add_user(users.reverse)
         }.trap{
           loading_image.pixbuf = Skin['notfound.png'].pixbuf(width: 128, height: 128)
         } end
@@ -87,19 +91,19 @@ Plugin.create :followingcontrol do
     container = Gtk::EventBox.new
     userlist = Gtk::UserList.new
     nativewidget container
-    if Service.map(&:user_obj).include?(retriever)
-    userlist.add_user(Users.new((relation.followers[retriever] || []).reverse))
+    if model.me?
+    userlist.add_user((relation.followers[model] || []).reverse)
       events = []
       events << on_followers_created do |service, created|
-        if service.user_obj == retriever
-          userlist.add_user(Users.new(created)) end end
+        if service.user_obj == model
+          userlist.add_user(created) end end
       events << on_followers_destroy do |service, destroyed|
-        if service.user_obj == retriever
-          userlist.remove_user(Users.new(destroyed)) end end
+        if service.user_obj == model
+          userlist.remove_user(destroyed) end end
       events << on_followers_modified do |service, modified|
-        if service.user_obj == retriever
+        if service.user_obj == model
           userlist.listview.model.clear
-          userlist.add_user(Users.new(modified.reverse)) end end
+          userlist.add_user(modified.reverse) end end
       userlist.ssc(:destroy) do
         events.each(&:detach) end
       container.add(userlist).show_all
@@ -107,11 +111,11 @@ Plugin.create :followingcontrol do
       container.ssc_atonce :expose_event do
         loading_image = Gtk::Image.new(Skin['loading.png'].pixbuf(width: 128, height: 128))
         container.add(loading_image.show_all)
-        Service.primary.followers(cache: true, user_id: retriever[:id]).next{ |users|
+        Service.primary.followers(cache: true, user_id: model[:id]).next{ |users|
           container.remove(loading_image)
           loading_image = nil
           container.add(userlist.show_all)
-          userlist.add_user(Users.new(users.reverse))
+          userlist.add_user(users.reverse)
         }.trap{
           loading_image.pixbuf = Skin['loading.png'].pixbuf(width: 128, height: 128)
         } end
@@ -122,26 +126,30 @@ Plugin.create :followingcontrol do
     @activating_services = Set.new
     @relation = Struct.new(:followings, :followers).new(TimeLimitedStorage.new, TimeLimitedStorage.new)
 
-    Service.each(&method(:service_register))
+    Enumerator.new{|y|
+      Plugin.filtering(:worlds, y)
+    }.select{|world|
+      world.class.slug == :twitter
+    }.each(&method(:service_register))
   end
 
   def relation
     @relation end
 
-  def rewind(direction, target)
+  def rewind(direction, targets)
     relation = @relation[direction.to_sym]
-    target.each { |service|
-      user = service.user_obj
-      service.__send__(direction, cache: :keep, user_id: user[:id]).next { |users|
+    targets.each { |twitter|
+      user = twitter.user_obj
+      twitter.__send__(direction, cache: :keep, user_id: user.id).next { |users|
         primitive = relation[user]
         if primitive and not primitive.empty?
           created = users - primitive
-          Plugin.call("#{direction}_created".to_sym, service, created) if not created.empty?
+          Plugin.call("#{direction}_created".to_sym, twitter, created) if not created.empty?
           destroyed = primitive - users
-          Plugin.call("#{direction}_destroy".to_sym, service, destroyed) if not destroyed.empty?
+          Plugin.call("#{direction}_destroy".to_sym, twitter, destroyed) if not destroyed.empty?
         else
-          relation[user] = Users.new(users)
-          Plugin.call("#{direction}_modified".to_sym, service, users)
+          relation[user] = users
+          Plugin.call("#{direction}_modified".to_sym, twitter, users)
         end
       }
     }
@@ -155,8 +163,8 @@ Plugin.create :followingcontrol do
     user = service.user_obj
     Deferred.when(service.followings(cache: true, user_id: user[:id]),
                   service.followers(cache: true, user_id: user[:id])).next { |followings, followers|
-      @relation.followings[user] = Users.new(followings)
-      @relation.followers[user] = Users.new(followers)
+      @relation.followings[user] = followings
+      @relation.followers[user] = followers
       Plugin.call(:followings_modified, service, @relation.followings[user])
       Plugin.call(:followers_modified, service, @relation.followers[user])
       @activating_services.delete(service)
@@ -165,5 +173,5 @@ Plugin.create :followingcontrol do
     }
   end
 
-  boot
+  Delayer.new{ boot }
 end
