@@ -8,6 +8,10 @@ module Mainloop
 
   def mainloop
     Gtk.main
+  rescue Interrupt,SystemExit,SignalException => exception
+    raise exception
+  rescue Exception => exception
+    Gtk.exception = exception
   end
 
   def exception_filter(e)
