@@ -31,6 +31,13 @@ Plugin.create :gui do
     else
       Plugin::GUI::Tab.instance(slug, name, self.name) end end
 
+  # タブが存在するか調べる。
+  # _tab_ メソッドは存在しないslugを指定した場合には常に作成してしまうため、存在を確認するのには使えない。
+  # 単純に存在確認をするにはこのメソッドを使う
+  defdsl :tab? do |slug|
+    Plugin::GUI::Tab.exist?(slug)
+  end
+
   # _slug_ に対応するタイムラインを返す
   # ==== Args
   # [slug] タイムラインのスラッグ
@@ -41,6 +48,13 @@ Plugin.create :gui do
     tl.instance_eval(&proc) if proc
     tl end
 
+  # タイムラインが存在するか調べる。
+  # _timeline_ メソッドは存在しないslugを指定した場合には常に作成してしまうため、存在を確認するのには使えない。
+  # 単純に存在確認をするにはこのメソッドを使う
+  defdsl :timeline? do |slug|
+    Plugin::GUI::Timeline.exist?(slug)
+  end
+
   # プロフィールタブを定義する
   # ==== Args
   # [slug] タブスラッグ
@@ -53,7 +67,7 @@ Plugin.create :gui do
                      fragment_slug = "#{slug}_#{user.uri}_#{Process.pid}_#{Time.now.to_i.to_s(16)}_#{rand(2 ** 32).to_s(16)}".to_sym
                      i_fragment = Plugin::GUI::Fragment.instance(fragment_slug, title)
                      i_cluster << i_fragment
-                     i_fragment.instance_eval{ @retriever = user }
+                     i_fragment.instance_eval{ @model = user }
                      handler_tag(fragment_slug) do |tag|
                        on_gui_destroy do |w|
                          detach(tag) if w == i_fragment end
@@ -72,13 +86,40 @@ Plugin.create :gui do
                      fragment_slug = "#{slug}_#{message.uri}_#{Process.pid}_#{Time.now.to_i.to_s(16)}_#{rand(2 ** 32).to_s(16)}".to_sym
                      i_fragment = Plugin::GUI::Fragment.instance(fragment_slug, title)
                      i_cluster << i_fragment
-                     i_fragment.instance_eval{ @retriever = message }
+                     i_fragment.instance_eval{ @model = message }
                      handler_tag(fragment_slug) do |tag|
                        on_gui_destroy do |w|
                          detach(tag) if w == i_fragment end
                        i_fragment.instance_eval_with_delegate(self, &proc) end } ])
       [tabs, i_cluster, message] end end
 
+  # ダイアログボックスを作成し表示する。
+  # ダイアログボックスの内容は _proc_ によって生成される。
+  # _proc_ からは、 _Gtk::FormDSL_ のメソッドを利用して内容を作成できる。
+  # ==== Args
+  # [title] ダイアログボックスタイトルバー等に表示されるテキスト(String)
+  # [default] エレメントのデフォルト値。{キー: デフォルト値}のようなHash
+  # ==== Return
+  # 入力の完了・中断を通知する _Delayer::Deferred_ 。
+  # OKボタンが押された場合は _next_ が、キャンセルが押されたり、ボタンを押さずにダイアログを閉じた場合は _trap_ が呼ばれる。
+  # ブロックに渡されるオブジェクトは:
+  # ===== OKボタンが押された場合
+  #     obj.ok? # => true
+  #     obj.state # => :ok
+  #     obj[:'フォームエレメントのキー(Symbol)'] # => フォームに入力されている値
+  #     obj.to_h # => {フォームエレメントのキー: フォームに入力されている値} のHash
+  # ===== キャンセルボタンが押された場合
+  #     obj.ok? # => false
+  #     obj.state # => :cancel
+  # ===== ボタンを押さずにダイアログを閉じられた場合
+  #     obj.ok? # => false
+  #     obj.state # => :close
+  defdsl :dialog do |title, default={}, &proc|
+    promise = Delayer::Deferred.new(true)
+    Plugin.call(:gui_dialog, self, title, default, proc, promise)
+    promise
+  end
+
   # obsolete
   defdsl :profiletab do |slug, title, &proc|
     warn 'Plugin#profiletab is obsolete. use Plugin#user_fragment'
