@@ -41,8 +41,7 @@ Plugin.create(:notify) do
   on_followers_created do |post, users|
     if not(users.empty?)
       if(UserConfig[:notify_followed])
-        users.each{ |user|
-          self.notify(users.first, _('%{users} にフォローされました。') % {users: users.map{|u| "@#{u[:idname]}" }.join(' ')}) } end
+        self.notify(users.first, _('%{users} にフォローされました。') % {users: users.map{|u| "@#{u[:idname]}" }.join(' ')}) end
       if(UserConfig[:notify_sound_followed])
         self.notify_sound(UserConfig[:notify_sound_followed]) end end end
 
