@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-miquire :lib, 'retriever/mixin/photo_mixin'
 
 module Plugin::Photo
-  class Photo < Retriever::Model
-    include Retriever::Model::PhotoMixin
+  class Photo < Diva::Model
+    include Diva::Model::PhotoMixin
     register :photo, name: Plugin[:photo]._('画像')
 
     field.uri :perma_link
@@ -16,7 +15,7 @@ module Plugin::Photo
       case uri
       when self
         uri
-      when URI, Addressable::URI, Retriever::URI, String
+      when URI, Addressable::URI, Diva::URI, String
         photos[uri.to_s.hash] ||= new(perma_link: uri)
       end
     end
