@@ -1,5 +1,5 @@
 # -*- coding:utf-8 -*-
-require File.expand_path(File.join(File.dirname(__FILE__), "shortcutkey_listview"))
+require_relative 'shortcutkey_listview'
 
 Plugin.create :shortcutkey do
 
