@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-miquire :lib, 'retriever/mixin/photo_mixin'
+miquire :core, 'skin'
 
 module Plugin::Skin
-  class Image < Retriever::Model
+  class Image < Diva::Model
     extend Memoist
-    include Retriever::Model::PhotoMixin
+
+    include Diva::Model::PhotoMixin
 
     register :skin_image, name: 'skin image'
 
@@ -16,7 +17,7 @@ module Plugin::Skin
     end
 
     memoize def uri
-      Retriever::URI.new(scheme: 'file'.freeze, path: path)
+      Diva::URI.new(scheme: 'file'.freeze, path: path)
     end
 
     # 引数の寸法の GdkPixbuf::Pixbuf を返す。
