@@ -23,7 +23,7 @@ Plugin.create :smartthread do
 
   command(:smartthread,
           name: _('会話スレッドを表示'),
-          icon: Skin.get("list.png"),
+          icon: Skin['list.png'],
           condition: lambda{ |opt| not opt.messages.empty? and opt.messages.all? &:repliable? },
           visible: true,
           role: :timeline){ |opt|
@@ -35,7 +35,7 @@ Plugin.create :smartthread do
     slug = "conversation#{serial}".to_sym
     tab slug, _("会話%{serial_id}") % {serial_id: serial} do
       set_deletable true
-      set_icon Skin.get("list.png")
+      set_icon Skin['list.png']
       temporary_tab
       timeline slug do
         order do |message|
