@@ -7,7 +7,7 @@ Web上のリソースを示す汎用的なModel。
 例えば、URLはWebブラウザで開くことができるが、intentは最終的に全てModelに変換できなければならないため、Modelが用意されていない多くのURLは取り扱うことができない。
 =end
 module Plugin::Web
-  class Web < Retriever::Model
+  class Web < Diva::Model
     register :web
 
     field.uri :perma_link
