@@ -149,7 +149,10 @@ class UserConfig
                                 :intent=>:message_detail_view_twitter_tweet,
                                 :model=>"",
                                 :str=>"https://twitter.com/",
-                                :rule=>"start"}]
+                                :rule=>"start"}],
+
+    :postbox_visibility => :auto,
+    :world_shifter_visibility => :auto,
   }
 
   @@watcher = Hash.new{ [] }
@@ -215,7 +218,10 @@ class UserConfig
     if last_boot_version < Environment::VERSION.to_a
       UserConfig[:last_boot_version] = Environment::VERSION.to_a
       if last_boot_version == [0, 0, 0, 0]
-        key_add "Alt + x", "コンソールを開く", :console_open end
+        key_add "Alt + x", "コンソールを開く", :console_open
+        UserConfig[:postbox_visibility] = :always
+        UserConfig[:world_shifter_visibility] = :always
+      end
       if last_boot_version < [3, 3, 0, 0]
         UserConfig[:notification_enable] = true
         activity_show_statusbar = (UserConfig[:activity_show_statusbar] || []).map(&:to_s)
